
========
Commands
========

.. note::

    To see a quick reference for any DPTools command, just run the command 
    with the ``--help`` or ``-h`` flag. For example,

    .. code-block:: console

        $ dptools run -h

Here is the complete list of dptools CLI commands. General usage follows the pattern,

.. code-block:: console

    $ dptools command [optional_args] required_args

Check each command page for detailed information and common scenarios/examples
for when it can be used.

.. toctree::
    :maxdepth: 1

    convert
    get
    info
    input
    parity
    reset
    run
    sample
    set
    train
